pub fn to_json(cat: &PluginApiCatalog, examples: Option<&Examples>) -> StringExpand description
The whole catalog as pretty-printed JSON, newline-terminated. examples
is the guest scan, or None to emit empty examples arrays.
pub fn to_json(cat: &PluginApiCatalog, examples: Option<&Examples>) -> StringThe whole catalog as pretty-printed JSON, newline-terminated. examples
is the guest scan, or None to emit empty examples arrays.