pub struct ApiMember {
pub name: String,
pub ty: Option<String>,
pub doc: Option<String>,
}Expand description
A record field, variant case, enum case or flag.
Fields
name: StringKebab-case member name.
ty: Option<String>The member’s type in WIT syntax: always present for a record field,
the payload for a variant case that has one, None otherwise.
doc: Option<String>The member’s /// doc comment, if any.