pub struct ApiUse {
pub name: String,
pub from: String,
pub original: String,
}Expand description
A type an interface imports from another with use.
Fields
name: StringThe name it is known by in this interface (after any as rename).
from: StringThe interface that defines it.
original: StringIts name in the defining interface.