pub fn capability_for(name: &str) -> Option<Capability>Expand description
The capability annotation for an interface, or None if unannotated (which
the coverage test forbids for any parsed interface).
pub fn capability_for(name: &str) -> Option<Capability>The capability annotation for an interface, or None if unannotated (which
the coverage test forbids for any parsed interface).